@@ -14,7 +14,7 @@ import (
 
 	units "github.com/docker/go-units"
 	"github.com/spf13/cobra"
-	"k8s.io/klog"
+	"k8s.io/klog/v2"
 
 	"github.com/docker/distribution"
 	"github.com/docker/distribution/manifest/schema2"
@@ -41,8 +41,8 @@ var (
 		Add layers to container images
 
 		Modifies an existing image by adding layers or changing configuration and then pushes that
-		image to a remote registry. Any inherited layers are streamed from registry to registry 
-		without being stored locally. The default docker credentials are used for authenticating 
+		image to a remote registry. Any inherited layers are streamed from registry to registry
+		without being stored locally. The default docker credentials are used for authenticating
 		to the registries.
 
 		Layers may be provided as arguments to the command and must each be a gzipped tar archive
@@ -54,21 +54,21 @@ var (
 		by passing a JSON string to the --image or --meta options. The --image flag changes what
 		the container runtime sees, while the --meta option allows you to change the attributes of
 		the image used by the runtime. Use --dry-run to see the result of your changes. You may
-		add the --drop-history flag to remove information from the image about the system that 
+		add the --drop-history flag to remove information from the image about the system that
 		built the base image.
 
 		Images in manifest list format will automatically select an image that matches the current
 		operating system and architecture unless you use --filter-by-os to select a different image.
 		This flag has no effect on regular images.
-		`)
+	`)
 
 	example = templates.Examples(`
-# Remove the entrypoint on the mysql:latest image
-%[1]s --from mysql:latest --to myregistry.com/myimage:latest --image {"Entrypoint":null}
+		# Remove the entrypoint on the mysql:latest image
+		oc image append --from mysql:latest --to myregistry.com/myimage:latest --image {"Entrypoint":null}
 
-# Add a new layer to the image
-%[1]s --from mysql:latest --to myregistry.com/myimage:latest layer.tar.gz
-`)
+		# Add a new layer to the image
+		oc image append --from mysql:latest --to myregistry.com/myimage:latest layer.tar.gz
+	`)
 )
 
 type AppendImageOptions struct {
@@ -107,14 +107,14 @@ func NewAppendImageOptions(streams genericclioptions.IOStreams) *AppendImageOpti
 }
 
 // New creates a new command
-func NewCmdAppendImage(name string, streams genericclioptions.IOStreams) *cobra.Command {
+func NewCmdAppendImage(streams genericclioptions.IOStreams) *cobra.Command {
 	o := NewAppendImageOptions(streams)
 
 	cmd := &cobra.Command{
 		Use:     "append",
 		Short:   "Add layers to images and push them to a registry",
 		Long:    desc,
-		Example: fmt.Sprintf(example, name+" append"),
+		Example: example,
 		Run: func(c *cobra.Command, args []string) {
 			kcmdutil.CheckErr(o.Complete(c, args))
 			kcmdutil.CheckErr(o.Validate())
@@ -285,7 +285,7 @@ func (o *AppendImageOptions) Run() error {
 			return err
 		}
 	} else {
-		if klog.V(4) {
+		if klog.V(4).Enabled() {
 			configJSON, _ := json.MarshalIndent(base, "", "  ")
 			klog.Infof("input config:\n%s\nlayers: %#v", configJSON, layers)
 		}
@@ -317,7 +317,7 @@ func (o *AppendImageOptions) Run() error {
 		}
 	}
 
-	if klog.V(4) {
+	if klog.V(4).Enabled() {
 		configJSON, _ := json.MarshalIndent(base, "", "  ")
 		klog.Infof("output config:\n%s", configJSON)
 	}
